# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateClusterDetails(object):
    """
    The properties that define a request to create a cluster.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateClusterDetails.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateClusterDetails.
        :type compartment_id: str

        :param endpoint_config:
            The value to assign to the endpoint_config property of this CreateClusterDetails.
        :type endpoint_config: oci.container_engine.models.CreateClusterEndpointConfigDetails

        :param vcn_id:
            The value to assign to the vcn_id property of this CreateClusterDetails.
        :type vcn_id: str

        :param kubernetes_version:
            The value to assign to the kubernetes_version property of this CreateClusterDetails.
        :type kubernetes_version: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this CreateClusterDetails.
        :type kms_key_id: str

        :param options:
            The value to assign to the options property of this CreateClusterDetails.
        :type options: oci.container_engine.models.ClusterCreateOptions

        :param image_policy_config:
            The value to assign to the image_policy_config property of this CreateClusterDetails.
        :type image_policy_config: oci.container_engine.models.CreateImagePolicyConfigDetails

        """
        self.swagger_types = {
            'name': 'str',
            'compartment_id': 'str',
            'endpoint_config': 'CreateClusterEndpointConfigDetails',
            'vcn_id': 'str',
            'kubernetes_version': 'str',
            'kms_key_id': 'str',
            'options': 'ClusterCreateOptions',
            'image_policy_config': 'CreateImagePolicyConfigDetails'
        }

        self.attribute_map = {
            'name': 'name',
            'compartment_id': 'compartmentId',
            'endpoint_config': 'endpointConfig',
            'vcn_id': 'vcnId',
            'kubernetes_version': 'kubernetesVersion',
            'kms_key_id': 'kmsKeyId',
            'options': 'options',
            'image_policy_config': 'imagePolicyConfig'
        }

        self._name = None
        self._compartment_id = None
        self._endpoint_config = None
        self._vcn_id = None
        self._kubernetes_version = None
        self._kms_key_id = None
        self._options = None
        self._image_policy_config = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateClusterDetails.
        The name of the cluster. Avoid entering confidential information.


        :return: The name of this CreateClusterDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateClusterDetails.
        The name of the cluster. Avoid entering confidential information.


        :param name: The name of this CreateClusterDetails.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateClusterDetails.
        The OCID of the compartment in which to create the cluster.


        :return: The compartment_id of this CreateClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateClusterDetails.
        The OCID of the compartment in which to create the cluster.


        :param compartment_id: The compartment_id of this CreateClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def endpoint_config(self):
        """
        Gets the endpoint_config of this CreateClusterDetails.
        The network configuration for access to the Cluster control plane.


        :return: The endpoint_config of this CreateClusterDetails.
        :rtype: oci.container_engine.models.CreateClusterEndpointConfigDetails
        """
        return self._endpoint_config

    @endpoint_config.setter
    def endpoint_config(self, endpoint_config):
        """
        Sets the endpoint_config of this CreateClusterDetails.
        The network configuration for access to the Cluster control plane.


        :param endpoint_config: The endpoint_config of this CreateClusterDetails.
        :type: oci.container_engine.models.CreateClusterEndpointConfigDetails
        """
        self._endpoint_config = endpoint_config

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this CreateClusterDetails.
        The OCID of the virtual cloud network (VCN) in which to create the cluster.


        :return: The vcn_id of this CreateClusterDetails.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this CreateClusterDetails.
        The OCID of the virtual cloud network (VCN) in which to create the cluster.


        :param vcn_id: The vcn_id of this CreateClusterDetails.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def kubernetes_version(self):
        """
        **[Required]** Gets the kubernetes_version of this CreateClusterDetails.
        The version of Kubernetes to install into the cluster masters.


        :return: The kubernetes_version of this CreateClusterDetails.
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """
        Sets the kubernetes_version of this CreateClusterDetails.
        The version of Kubernetes to install into the cluster masters.


        :param kubernetes_version: The kubernetes_version of this CreateClusterDetails.
        :type: str
        """
        self._kubernetes_version = kubernetes_version

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this CreateClusterDetails.
        The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.
        When used, `kubernetesVersion` must be at least `v1.13.0`.


        :return: The kms_key_id of this CreateClusterDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this CreateClusterDetails.
        The OCID of the KMS key to be used as the master encryption key for Kubernetes secret encryption.
        When used, `kubernetesVersion` must be at least `v1.13.0`.


        :param kms_key_id: The kms_key_id of this CreateClusterDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def options(self):
        """
        Gets the options of this CreateClusterDetails.
        Optional attributes for the cluster.


        :return: The options of this CreateClusterDetails.
        :rtype: oci.container_engine.models.ClusterCreateOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this CreateClusterDetails.
        Optional attributes for the cluster.


        :param options: The options of this CreateClusterDetails.
        :type: oci.container_engine.models.ClusterCreateOptions
        """
        self._options = options

    @property
    def image_policy_config(self):
        """
        Gets the image_policy_config of this CreateClusterDetails.
        The image verification policy for signature validation. Once a policy is created and enabled with
        one or more kms keys, the policy will ensure all images deployed has been signed with the key(s)
        attached to the policy.


        :return: The image_policy_config of this CreateClusterDetails.
        :rtype: oci.container_engine.models.CreateImagePolicyConfigDetails
        """
        return self._image_policy_config

    @image_policy_config.setter
    def image_policy_config(self, image_policy_config):
        """
        Sets the image_policy_config of this CreateClusterDetails.
        The image verification policy for signature validation. Once a policy is created and enabled with
        one or more kms keys, the policy will ensure all images deployed has been signed with the key(s)
        attached to the policy.


        :param image_policy_config: The image_policy_config of this CreateClusterDetails.
        :type: oci.container_engine.models.CreateImagePolicyConfigDetails
        """
        self._image_policy_config = image_policy_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .operator import Operator
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Lookup(Operator):
    """
    The information about the lookup operator. The lookup operator has two input links, a primary input, and a lookup source input. It has an output link, fields of the lookup input are appended to the primary input and projected as the output fields.
    """

    #: A constant which can be used with the multi_match_strategy property of a Lookup.
    #: This constant has a value of "RETURN_ANY"
    MULTI_MATCH_STRATEGY_RETURN_ANY = "RETURN_ANY"

    #: A constant which can be used with the multi_match_strategy property of a Lookup.
    #: This constant has a value of "RETURN_FIRST"
    MULTI_MATCH_STRATEGY_RETURN_FIRST = "RETURN_FIRST"

    #: A constant which can be used with the multi_match_strategy property of a Lookup.
    #: This constant has a value of "RETURN_LAST"
    MULTI_MATCH_STRATEGY_RETURN_LAST = "RETURN_LAST"

    #: A constant which can be used with the multi_match_strategy property of a Lookup.
    #: This constant has a value of "RETURN_ALL"
    MULTI_MATCH_STRATEGY_RETURN_ALL = "RETURN_ALL"

    #: A constant which can be used with the multi_match_strategy property of a Lookup.
    #: This constant has a value of "RETURN_ERROR"
    MULTI_MATCH_STRATEGY_RETURN_ERROR = "RETURN_ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new Lookup object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.Lookup.model_type` attribute
        of this class is ``LOOKUP_OPERATOR`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this Lookup.
            Allowed values for this property are: "SOURCE_OPERATOR", "FILTER_OPERATOR", "JOINER_OPERATOR", "AGGREGATOR_OPERATOR", "PROJECTION_OPERATOR", "TARGET_OPERATOR", "DISTINCT_OPERATOR", "SORT_OPERATOR", "UNION_OPERATOR", "INTERSECT_OPERATOR", "MINUS_OPERATOR", "MERGE_OPERATOR", "START_OPERATOR", "END_OPERATOR", "PIPELINE_OPERATOR", "TASK_OPERATOR", "EXPRESSION_OPERATOR", "LOOKUP_OPERATOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this Lookup.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this Lookup.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this Lookup.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this Lookup.
        :type name: str

        :param description:
            The value to assign to the description property of this Lookup.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this Lookup.
        :type object_version: int

        :param input_ports:
            The value to assign to the input_ports property of this Lookup.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this Lookup.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param object_status:
            The value to assign to the object_status property of this Lookup.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this Lookup.
        :type identifier: str

        :param parameters:
            The value to assign to the parameters property of this Lookup.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this Lookup.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param lookup_condition:
            The value to assign to the lookup_condition property of this Lookup.
        :type lookup_condition: oci.data_integration.models.Expression

        :param is_skip_no_match:
            The value to assign to the is_skip_no_match property of this Lookup.
        :type is_skip_no_match: bool

        :param multi_match_strategy:
            The value to assign to the multi_match_strategy property of this Lookup.
            Allowed values for this property are: "RETURN_ANY", "RETURN_FIRST", "RETURN_LAST", "RETURN_ALL", "RETURN_ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type multi_match_strategy: str

        :param null_fill_values:
            The value to assign to the null_fill_values property of this Lookup.
        :type null_fill_values: dict(str, object)

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'object_status': 'int',
            'identifier': 'str',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'lookup_condition': 'Expression',
            'is_skip_no_match': 'bool',
            'multi_match_strategy': 'str',
            'null_fill_values': 'dict(str, object)'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'lookup_condition': 'lookupCondition',
            'is_skip_no_match': 'isSkipNoMatch',
            'multi_match_strategy': 'multiMatchStrategy',
            'null_fill_values': 'nullFillValues'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._input_ports = None
        self._output_ports = None
        self._object_status = None
        self._identifier = None
        self._parameters = None
        self._op_config_values = None
        self._lookup_condition = None
        self._is_skip_no_match = None
        self._multi_match_strategy = None
        self._null_fill_values = None
        self._model_type = 'LOOKUP_OPERATOR'

    @property
    def lookup_condition(self):
        """
        Gets the lookup_condition of this Lookup.

        :return: The lookup_condition of this Lookup.
        :rtype: oci.data_integration.models.Expression
        """
        return self._lookup_condition

    @lookup_condition.setter
    def lookup_condition(self, lookup_condition):
        """
        Sets the lookup_condition of this Lookup.

        :param lookup_condition: The lookup_condition of this Lookup.
        :type: oci.data_integration.models.Expression
        """
        self._lookup_condition = lookup_condition

    @property
    def is_skip_no_match(self):
        """
        Gets the is_skip_no_match of this Lookup.
        For the rows for which lookup condition does not satisfy, if set to true - do not return those rows of primary Input source and if set to false - create a row with primary input fields values and lookup field values as NULL.


        :return: The is_skip_no_match of this Lookup.
        :rtype: bool
        """
        return self._is_skip_no_match

    @is_skip_no_match.setter
    def is_skip_no_match(self, is_skip_no_match):
        """
        Sets the is_skip_no_match of this Lookup.
        For the rows for which lookup condition does not satisfy, if set to true - do not return those rows of primary Input source and if set to false - create a row with primary input fields values and lookup field values as NULL.


        :param is_skip_no_match: The is_skip_no_match of this Lookup.
        :type: bool
        """
        self._is_skip_no_match = is_skip_no_match

    @property
    def multi_match_strategy(self):
        """
        Gets the multi_match_strategy of this Lookup.
        if there are multiple records found in the lookup input what action should be performed. The default value for this field is RETURN_ANY.

        Allowed values for this property are: "RETURN_ANY", "RETURN_FIRST", "RETURN_LAST", "RETURN_ALL", "RETURN_ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The multi_match_strategy of this Lookup.
        :rtype: str
        """
        return self._multi_match_strategy

    @multi_match_strategy.setter
    def multi_match_strategy(self, multi_match_strategy):
        """
        Sets the multi_match_strategy of this Lookup.
        if there are multiple records found in the lookup input what action should be performed. The default value for this field is RETURN_ANY.


        :param multi_match_strategy: The multi_match_strategy of this Lookup.
        :type: str
        """
        allowed_values = ["RETURN_ANY", "RETURN_FIRST", "RETURN_LAST", "RETURN_ALL", "RETURN_ERROR"]
        if not value_allowed_none_or_none_sentinel(multi_match_strategy, allowed_values):
            multi_match_strategy = 'UNKNOWN_ENUM_VALUE'
        self._multi_match_strategy = multi_match_strategy

    @property
    def null_fill_values(self):
        """
        Gets the null_fill_values of this Lookup.
        this map is used for replacing NULL values in the record. Key is the column name and value is the NULL replacement.


        :return: The null_fill_values of this Lookup.
        :rtype: dict(str, object)
        """
        return self._null_fill_values

    @null_fill_values.setter
    def null_fill_values(self, null_fill_values):
        """
        Sets the null_fill_values of this Lookup.
        this map is used for replacing NULL values in the record. Key is the column name and value is the NULL replacement.


        :param null_fill_values: The null_fill_values of this Lookup.
        :type: dict(str, object)
        """
        self._null_fill_values = null_fill_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HttpProbeResultSummary(object):
    """
    The results returned by running an HTTP probe.  All times and durations are
    returned in milliseconds. All times are relative to the POSIX epoch
    (1970-01-01T00:00Z). Time properties conform to W3C Resource Timing.
    For more information, see
    `PerformanceResourceTiming`__
    interface.

    __ https://w3c.github.io/resource-timing/#sec-resource-timing
    """

    #: A constant which can be used with the error_category property of a HttpProbeResultSummary.
    #: This constant has a value of "NONE"
    ERROR_CATEGORY_NONE = "NONE"

    #: A constant which can be used with the error_category property of a HttpProbeResultSummary.
    #: This constant has a value of "DNS"
    ERROR_CATEGORY_DNS = "DNS"

    #: A constant which can be used with the error_category property of a HttpProbeResultSummary.
    #: This constant has a value of "TRANSPORT"
    ERROR_CATEGORY_TRANSPORT = "TRANSPORT"

    #: A constant which can be used with the error_category property of a HttpProbeResultSummary.
    #: This constant has a value of "NETWORK"
    ERROR_CATEGORY_NETWORK = "NETWORK"

    #: A constant which can be used with the error_category property of a HttpProbeResultSummary.
    #: This constant has a value of "SYSTEM"
    ERROR_CATEGORY_SYSTEM = "SYSTEM"

    #: A constant which can be used with the protocol property of a HttpProbeResultSummary.
    #: This constant has a value of "HTTP"
    PROTOCOL_HTTP = "HTTP"

    #: A constant which can be used with the protocol property of a HttpProbeResultSummary.
    #: This constant has a value of "HTTPS"
    PROTOCOL_HTTPS = "HTTPS"

    def __init__(self, **kwargs):
        """
        Initializes a new HttpProbeResultSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this HttpProbeResultSummary.
        :type key: str

        :param probe_configuration_id:
            The value to assign to the probe_configuration_id property of this HttpProbeResultSummary.
        :type probe_configuration_id: str

        :param start_time:
            The value to assign to the start_time property of this HttpProbeResultSummary.
        :type start_time: float

        :param target:
            The value to assign to the target property of this HttpProbeResultSummary.
        :type target: str

        :param vantage_point_name:
            The value to assign to the vantage_point_name property of this HttpProbeResultSummary.
        :type vantage_point_name: str

        :param is_timed_out:
            The value to assign to the is_timed_out property of this HttpProbeResultSummary.
        :type is_timed_out: bool

        :param is_healthy:
            The value to assign to the is_healthy property of this HttpProbeResultSummary.
        :type is_healthy: bool

        :param error_category:
            The value to assign to the error_category property of this HttpProbeResultSummary.
            Allowed values for this property are: "NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type error_category: str

        :param error_message:
            The value to assign to the error_message property of this HttpProbeResultSummary.
        :type error_message: str

        :param protocol:
            The value to assign to the protocol property of this HttpProbeResultSummary.
            Allowed values for this property are: "HTTP", "HTTPS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param connection:
            The value to assign to the connection property of this HttpProbeResultSummary.
        :type connection: oci.healthchecks.models.TcpConnection

        :param dns:
            The value to assign to the dns property of this HttpProbeResultSummary.
        :type dns: oci.healthchecks.models.DNS

        :param status_code:
            The value to assign to the status_code property of this HttpProbeResultSummary.
        :type status_code: int

        :param domain_lookup_start:
            The value to assign to the domain_lookup_start property of this HttpProbeResultSummary.
        :type domain_lookup_start: float

        :param domain_lookup_end:
            The value to assign to the domain_lookup_end property of this HttpProbeResultSummary.
        :type domain_lookup_end: float

        :param connect_start:
            The value to assign to the connect_start property of this HttpProbeResultSummary.
        :type connect_start: float

        :param secure_connection_start:
            The value to assign to the secure_connection_start property of this HttpProbeResultSummary.
        :type secure_connection_start: float

        :param connect_end:
            The value to assign to the connect_end property of this HttpProbeResultSummary.
        :type connect_end: float

        :param fetch_start:
            The value to assign to the fetch_start property of this HttpProbeResultSummary.
        :type fetch_start: float

        :param request_start:
            The value to assign to the request_start property of this HttpProbeResultSummary.
        :type request_start: float

        :param response_start:
            The value to assign to the response_start property of this HttpProbeResultSummary.
        :type response_start: float

        :param response_end:
            The value to assign to the response_end property of this HttpProbeResultSummary.
        :type response_end: float

        :param duration:
            The value to assign to the duration property of this HttpProbeResultSummary.
        :type duration: float

        :param encoded_body_size:
            The value to assign to the encoded_body_size property of this HttpProbeResultSummary.
        :type encoded_body_size: int

        """
        self.swagger_types = {
            'key': 'str',
            'probe_configuration_id': 'str',
            'start_time': 'float',
            'target': 'str',
            'vantage_point_name': 'str',
            'is_timed_out': 'bool',
            'is_healthy': 'bool',
            'error_category': 'str',
            'error_message': 'str',
            'protocol': 'str',
            'connection': 'TcpConnection',
            'dns': 'DNS',
            'status_code': 'int',
            'domain_lookup_start': 'float',
            'domain_lookup_end': 'float',
            'connect_start': 'float',
            'secure_connection_start': 'float',
            'connect_end': 'float',
            'fetch_start': 'float',
            'request_start': 'float',
            'response_start': 'float',
            'response_end': 'float',
            'duration': 'float',
            'encoded_body_size': 'int'
        }

        self.attribute_map = {
            'key': 'key',
            'probe_configuration_id': 'probeConfigurationId',
            'start_time': 'startTime',
            'target': 'target',
            'vantage_point_name': 'vantagePointName',
            'is_timed_out': 'isTimedOut',
            'is_healthy': 'isHealthy',
            'error_category': 'errorCategory',
            'error_message': 'errorMessage',
            'protocol': 'protocol',
            'connection': 'connection',
            'dns': 'dns',
            'status_code': 'statusCode',
            'domain_lookup_start': 'domainLookupStart',
            'domain_lookup_end': 'domainLookupEnd',
            'connect_start': 'connectStart',
            'secure_connection_start': 'secureConnectionStart',
            'connect_end': 'connectEnd',
            'fetch_start': 'fetchStart',
            'request_start': 'requestStart',
            'response_start': 'responseStart',
            'response_end': 'responseEnd',
            'duration': 'duration',
            'encoded_body_size': 'encodedBodySize'
        }

        self._key = None
        self._probe_configuration_id = None
        self._start_time = None
        self._target = None
        self._vantage_point_name = None
        self._is_timed_out = None
        self._is_healthy = None
        self._error_category = None
        self._error_message = None
        self._protocol = None
        self._connection = None
        self._dns = None
        self._status_code = None
        self._domain_lookup_start = None
        self._domain_lookup_end = None
        self._connect_start = None
        self._secure_connection_start = None
        self._connect_end = None
        self._fetch_start = None
        self._request_start = None
        self._response_start = None
        self._response_end = None
        self._duration = None
        self._encoded_body_size = None

    @property
    def key(self):
        """
        Gets the key of this HttpProbeResultSummary.
        A value identifying this specific probe result. The key is only unique within
        the results of its probe configuration. The key may be reused after 90 days.


        :return: The key of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this HttpProbeResultSummary.
        A value identifying this specific probe result. The key is only unique within
        the results of its probe configuration. The key may be reused after 90 days.


        :param key: The key of this HttpProbeResultSummary.
        :type: str
        """
        self._key = key

    @property
    def probe_configuration_id(self):
        """
        Gets the probe_configuration_id of this HttpProbeResultSummary.
        The OCID of the monitor or on-demand probe responsible for creating this result.


        :return: The probe_configuration_id of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._probe_configuration_id

    @probe_configuration_id.setter
    def probe_configuration_id(self, probe_configuration_id):
        """
        Sets the probe_configuration_id of this HttpProbeResultSummary.
        The OCID of the monitor or on-demand probe responsible for creating this result.


        :param probe_configuration_id: The probe_configuration_id of this HttpProbeResultSummary.
        :type: str
        """
        self._probe_configuration_id = probe_configuration_id

    @property
    def start_time(self):
        """
        Gets the start_time of this HttpProbeResultSummary.
        The date and time the probe was executed, expressed in milliseconds since the
        POSIX epoch. This field is defined by the PerformanceResourceTiming interface
        of the W3C Resource Timing specification. For more information, see
        `Resource Timing`__.

        __ https://w3c.github.io/resource-timing/#sec-resource-timing


        :return: The start_time of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this HttpProbeResultSummary.
        The date and time the probe was executed, expressed in milliseconds since the
        POSIX epoch. This field is defined by the PerformanceResourceTiming interface
        of the W3C Resource Timing specification. For more information, see
        `Resource Timing`__.

        __ https://w3c.github.io/resource-timing/#sec-resource-timing


        :param start_time: The start_time of this HttpProbeResultSummary.
        :type: float
        """
        self._start_time = start_time

    @property
    def target(self):
        """
        Gets the target of this HttpProbeResultSummary.
        The target hostname or IP address of the probe.


        :return: The target of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this HttpProbeResultSummary.
        The target hostname or IP address of the probe.


        :param target: The target of this HttpProbeResultSummary.
        :type: str
        """
        self._target = target

    @property
    def vantage_point_name(self):
        """
        Gets the vantage_point_name of this HttpProbeResultSummary.
        The name of the vantage point that executed the probe.


        :return: The vantage_point_name of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._vantage_point_name

    @vantage_point_name.setter
    def vantage_point_name(self, vantage_point_name):
        """
        Sets the vantage_point_name of this HttpProbeResultSummary.
        The name of the vantage point that executed the probe.


        :param vantage_point_name: The vantage_point_name of this HttpProbeResultSummary.
        :type: str
        """
        self._vantage_point_name = vantage_point_name

    @property
    def is_timed_out(self):
        """
        Gets the is_timed_out of this HttpProbeResultSummary.
        True if the probe did not complete before the configured `timeoutInSeconds` value.


        :return: The is_timed_out of this HttpProbeResultSummary.
        :rtype: bool
        """
        return self._is_timed_out

    @is_timed_out.setter
    def is_timed_out(self, is_timed_out):
        """
        Sets the is_timed_out of this HttpProbeResultSummary.
        True if the probe did not complete before the configured `timeoutInSeconds` value.


        :param is_timed_out: The is_timed_out of this HttpProbeResultSummary.
        :type: bool
        """
        self._is_timed_out = is_timed_out

    @property
    def is_healthy(self):
        """
        Gets the is_healthy of this HttpProbeResultSummary.
        True if the probe result is determined to be healthy based on probe
        type-specific criteria.  For HTTP probes, a probe result is considered
        healthy if the HTTP response code is greater than or equal to 200 and
        less than 300.


        :return: The is_healthy of this HttpProbeResultSummary.
        :rtype: bool
        """
        return self._is_healthy

    @is_healthy.setter
    def is_healthy(self, is_healthy):
        """
        Sets the is_healthy of this HttpProbeResultSummary.
        True if the probe result is determined to be healthy based on probe
        type-specific criteria.  For HTTP probes, a probe result is considered
        healthy if the HTTP response code is greater than or equal to 200 and
        less than 300.


        :param is_healthy: The is_healthy of this HttpProbeResultSummary.
        :type: bool
        """
        self._is_healthy = is_healthy

    @property
    def error_category(self):
        """
        Gets the error_category of this HttpProbeResultSummary.
        The category of error if an error occurs executing the probe.
        The `errorMessage` field provides a message with the error details.
        * NONE - No error
        * DNS - DNS errors
        * TRANSPORT - Transport-related errors, for example a \"TLS certificate expired\" error.
        * NETWORK - Network-related errors, for example a \"network unreachable\" error.
        * SYSTEM - Internal system errors.

        Allowed values for this property are: "NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The error_category of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._error_category

    @error_category.setter
    def error_category(self, error_category):
        """
        Sets the error_category of this HttpProbeResultSummary.
        The category of error if an error occurs executing the probe.
        The `errorMessage` field provides a message with the error details.
        * NONE - No error
        * DNS - DNS errors
        * TRANSPORT - Transport-related errors, for example a \"TLS certificate expired\" error.
        * NETWORK - Network-related errors, for example a \"network unreachable\" error.
        * SYSTEM - Internal system errors.


        :param error_category: The error_category of this HttpProbeResultSummary.
        :type: str
        """
        allowed_values = ["NONE", "DNS", "TRANSPORT", "NETWORK", "SYSTEM"]
        if not value_allowed_none_or_none_sentinel(error_category, allowed_values):
            error_category = 'UNKNOWN_ENUM_VALUE'
        self._error_category = error_category

    @property
    def error_message(self):
        """
        Gets the error_message of this HttpProbeResultSummary.
        The error information indicating why a probe execution failed.


        :return: The error_message of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this HttpProbeResultSummary.
        The error information indicating why a probe execution failed.


        :param error_message: The error_message of this HttpProbeResultSummary.
        :type: str
        """
        self._error_message = error_message

    @property
    def protocol(self):
        """
        Gets the protocol of this HttpProbeResultSummary.
        Allowed values for this property are: "HTTP", "HTTPS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this HttpProbeResultSummary.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this HttpProbeResultSummary.

        :param protocol: The protocol of this HttpProbeResultSummary.
        :type: str
        """
        allowed_values = ["HTTP", "HTTPS"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def connection(self):
        """
        Gets the connection of this HttpProbeResultSummary.

        :return: The connection of this HttpProbeResultSummary.
        :rtype: oci.healthchecks.models.TcpConnection
        """
        return self._connection

    @connection.setter
    def connection(self, connection):
        """
        Sets the connection of this HttpProbeResultSummary.

        :param connection: The connection of this HttpProbeResultSummary.
        :type: oci.healthchecks.models.TcpConnection
        """
        self._connection = connection

    @property
    def dns(self):
        """
        Gets the dns of this HttpProbeResultSummary.

        :return: The dns of this HttpProbeResultSummary.
        :rtype: oci.healthchecks.models.DNS
        """
        return self._dns

    @dns.setter
    def dns(self, dns):
        """
        Sets the dns of this HttpProbeResultSummary.

        :param dns: The dns of this HttpProbeResultSummary.
        :type: oci.healthchecks.models.DNS
        """
        self._dns = dns

    @property
    def status_code(self):
        """
        Gets the status_code of this HttpProbeResultSummary.
        The HTTP response status code.


        :return: The status_code of this HttpProbeResultSummary.
        :rtype: int
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """
        Sets the status_code of this HttpProbeResultSummary.
        The HTTP response status code.


        :param status_code: The status_code of this HttpProbeResultSummary.
        :type: int
        """
        self._status_code = status_code

    @property
    def domain_lookup_start(self):
        """
        Gets the domain_lookup_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts the domain name lookup for
        the resource.


        :return: The domain_lookup_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._domain_lookup_start

    @domain_lookup_start.setter
    def domain_lookup_start(self, domain_lookup_start):
        """
        Sets the domain_lookup_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts the domain name lookup for
        the resource.


        :param domain_lookup_start: The domain_lookup_start of this HttpProbeResultSummary.
        :type: float
        """
        self._domain_lookup_start = domain_lookup_start

    @property
    def domain_lookup_end(self):
        """
        Gets the domain_lookup_end of this HttpProbeResultSummary.
        The time immediately before the vantage point finishes the domain name lookup for
        the resource.


        :return: The domain_lookup_end of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._domain_lookup_end

    @domain_lookup_end.setter
    def domain_lookup_end(self, domain_lookup_end):
        """
        Sets the domain_lookup_end of this HttpProbeResultSummary.
        The time immediately before the vantage point finishes the domain name lookup for
        the resource.


        :param domain_lookup_end: The domain_lookup_end of this HttpProbeResultSummary.
        :type: float
        """
        self._domain_lookup_end = domain_lookup_end

    @property
    def connect_start(self):
        """
        Gets the connect_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts establishing the connection
        to the server to retrieve the resource.


        :return: The connect_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._connect_start

    @connect_start.setter
    def connect_start(self, connect_start):
        """
        Sets the connect_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts establishing the connection
        to the server to retrieve the resource.


        :param connect_start: The connect_start of this HttpProbeResultSummary.
        :type: float
        """
        self._connect_start = connect_start

    @property
    def secure_connection_start(self):
        """
        Gets the secure_connection_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts the handshake process to
        secure the current connection.


        :return: The secure_connection_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._secure_connection_start

    @secure_connection_start.setter
    def secure_connection_start(self, secure_connection_start):
        """
        Sets the secure_connection_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts the handshake process to
        secure the current connection.


        :param secure_connection_start: The secure_connection_start of this HttpProbeResultSummary.
        :type: float
        """
        self._secure_connection_start = secure_connection_start

    @property
    def connect_end(self):
        """
        Gets the connect_end of this HttpProbeResultSummary.
        The time immediately after the vantage point finishes establishing the connection
        to the server to retrieve the resource.


        :return: The connect_end of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._connect_end

    @connect_end.setter
    def connect_end(self, connect_end):
        """
        Sets the connect_end of this HttpProbeResultSummary.
        The time immediately after the vantage point finishes establishing the connection
        to the server to retrieve the resource.


        :param connect_end: The connect_end of this HttpProbeResultSummary.
        :type: float
        """
        self._connect_end = connect_end

    @property
    def fetch_start(self):
        """
        Gets the fetch_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts to fetch the resource.


        :return: The fetch_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._fetch_start

    @fetch_start.setter
    def fetch_start(self, fetch_start):
        """
        Sets the fetch_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts to fetch the resource.


        :param fetch_start: The fetch_start of this HttpProbeResultSummary.
        :type: float
        """
        self._fetch_start = fetch_start

    @property
    def request_start(self):
        """
        Gets the request_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts requesting the resource from
        the server.


        :return: The request_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._request_start

    @request_start.setter
    def request_start(self, request_start):
        """
        Sets the request_start of this HttpProbeResultSummary.
        The time immediately before the vantage point starts requesting the resource from
        the server.


        :param request_start: The request_start of this HttpProbeResultSummary.
        :type: float
        """
        self._request_start = request_start

    @property
    def response_start(self):
        """
        Gets the response_start of this HttpProbeResultSummary.
        The time immediately after the vantage point's HTTP parser receives the first byte
        of the response.


        :return: The response_start of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._response_start

    @response_start.setter
    def response_start(self, response_start):
        """
        Sets the response_start of this HttpProbeResultSummary.
        The time immediately after the vantage point's HTTP parser receives the first byte
        of the response.


        :param response_start: The response_start of this HttpProbeResultSummary.
        :type: float
        """
        self._response_start = response_start

    @property
    def response_end(self):
        """
        Gets the response_end of this HttpProbeResultSummary.
        The time immediately after the vantage point receives the last byte of the response
        or immediately before the transport connection is closed, whichever comes first.


        :return: The response_end of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._response_end

    @response_end.setter
    def response_end(self, response_end):
        """
        Sets the response_end of this HttpProbeResultSummary.
        The time immediately after the vantage point receives the last byte of the response
        or immediately before the transport connection is closed, whichever comes first.


        :param response_end: The response_end of this HttpProbeResultSummary.
        :type: float
        """
        self._response_end = response_end

    @property
    def duration(self):
        """
        Gets the duration of this HttpProbeResultSummary.
        The total duration from start of request until response is fully consumed or the
        connection is closed.


        :return: The duration of this HttpProbeResultSummary.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """
        Sets the duration of this HttpProbeResultSummary.
        The total duration from start of request until response is fully consumed or the
        connection is closed.


        :param duration: The duration of this HttpProbeResultSummary.
        :type: float
        """
        self._duration = duration

    @property
    def encoded_body_size(self):
        """
        Gets the encoded_body_size of this HttpProbeResultSummary.
        The size, in octets, of the payload body prior to removing any applied
        content-codings.


        :return: The encoded_body_size of this HttpProbeResultSummary.
        :rtype: int
        """
        return self._encoded_body_size

    @encoded_body_size.setter
    def encoded_body_size(self, encoded_body_size):
        """
        Sets the encoded_body_size of this HttpProbeResultSummary.
        The size, in octets, of the payload body prior to removing any applied
        content-codings.


        :param encoded_body_size: The encoded_body_size of this HttpProbeResultSummary.
        :type: int
        """
        self._encoded_body_size = encoded_body_size

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Recommendation(object):
    """
    The metadata associated with the recommendation.
    """

    #: A constant which can be used with the importance property of a Recommendation.
    #: This constant has a value of "CRITICAL"
    IMPORTANCE_CRITICAL = "CRITICAL"

    #: A constant which can be used with the importance property of a Recommendation.
    #: This constant has a value of "HIGH"
    IMPORTANCE_HIGH = "HIGH"

    #: A constant which can be used with the importance property of a Recommendation.
    #: This constant has a value of "MODERATE"
    IMPORTANCE_MODERATE = "MODERATE"

    #: A constant which can be used with the importance property of a Recommendation.
    #: This constant has a value of "LOW"
    IMPORTANCE_LOW = "LOW"

    #: A constant which can be used with the importance property of a Recommendation.
    #: This constant has a value of "MINOR"
    IMPORTANCE_MINOR = "MINOR"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "ATTACHING"
    LIFECYCLE_STATE_ATTACHING = "ATTACHING"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "DETACHING"
    LIFECYCLE_STATE_DETACHING = "DETACHING"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Recommendation.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the status property of a Recommendation.
    #: This constant has a value of "PENDING"
    STATUS_PENDING = "PENDING"

    #: A constant which can be used with the status property of a Recommendation.
    #: This constant has a value of "DISMISSED"
    STATUS_DISMISSED = "DISMISSED"

    #: A constant which can be used with the status property of a Recommendation.
    #: This constant has a value of "POSTPONED"
    STATUS_POSTPONED = "POSTPONED"

    #: A constant which can be used with the status property of a Recommendation.
    #: This constant has a value of "IMPLEMENTED"
    STATUS_IMPLEMENTED = "IMPLEMENTED"

    def __init__(self, **kwargs):
        """
        Initializes a new Recommendation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Recommendation.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Recommendation.
        :type compartment_id: str

        :param category_id:
            The value to assign to the category_id property of this Recommendation.
        :type category_id: str

        :param name:
            The value to assign to the name property of this Recommendation.
        :type name: str

        :param description:
            The value to assign to the description property of this Recommendation.
        :type description: str

        :param importance:
            The value to assign to the importance property of this Recommendation.
            Allowed values for this property are: "CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type importance: str

        :param resource_counts:
            The value to assign to the resource_counts property of this Recommendation.
        :type resource_counts: list[oci.optimizer.models.ResourceCount]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Recommendation.
            Allowed values for this property are: "ACTIVE", "FAILED", "INACTIVE", "ATTACHING", "DETACHING", "DELETING", "DELETED", "UPDATING", "CREATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param estimated_cost_saving:
            The value to assign to the estimated_cost_saving property of this Recommendation.
        :type estimated_cost_saving: float

        :param status:
            The value to assign to the status property of this Recommendation.
            Allowed values for this property are: "PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_status_begin:
            The value to assign to the time_status_begin property of this Recommendation.
        :type time_status_begin: datetime

        :param time_status_end:
            The value to assign to the time_status_end property of this Recommendation.
        :type time_status_end: datetime

        :param time_created:
            The value to assign to the time_created property of this Recommendation.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Recommendation.
        :type time_updated: datetime

        :param supported_levels:
            The value to assign to the supported_levels property of this Recommendation.
        :type supported_levels: oci.optimizer.models.SupportedLevels

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'category_id': 'str',
            'name': 'str',
            'description': 'str',
            'importance': 'str',
            'resource_counts': 'list[ResourceCount]',
            'lifecycle_state': 'str',
            'estimated_cost_saving': 'float',
            'status': 'str',
            'time_status_begin': 'datetime',
            'time_status_end': 'datetime',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'supported_levels': 'SupportedLevels'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'category_id': 'categoryId',
            'name': 'name',
            'description': 'description',
            'importance': 'importance',
            'resource_counts': 'resourceCounts',
            'lifecycle_state': 'lifecycleState',
            'estimated_cost_saving': 'estimatedCostSaving',
            'status': 'status',
            'time_status_begin': 'timeStatusBegin',
            'time_status_end': 'timeStatusEnd',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'supported_levels': 'supportedLevels'
        }

        self._id = None
        self._compartment_id = None
        self._category_id = None
        self._name = None
        self._description = None
        self._importance = None
        self._resource_counts = None
        self._lifecycle_state = None
        self._estimated_cost_saving = None
        self._status = None
        self._time_status_begin = None
        self._time_status_end = None
        self._time_created = None
        self._time_updated = None
        self._supported_levels = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Recommendation.
        The unique OCID associated with the recommendation.


        :return: The id of this Recommendation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Recommendation.
        The unique OCID associated with the recommendation.


        :param id: The id of this Recommendation.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Recommendation.
        The OCID of the tenancy. The tenancy is the root compartment.


        :return: The compartment_id of this Recommendation.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Recommendation.
        The OCID of the tenancy. The tenancy is the root compartment.


        :param compartment_id: The compartment_id of this Recommendation.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def category_id(self):
        """
        **[Required]** Gets the category_id of this Recommendation.
        The unique OCID associated with the category.


        :return: The category_id of this Recommendation.
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """
        Sets the category_id of this Recommendation.
        The unique OCID associated with the category.


        :param category_id: The category_id of this Recommendation.
        :type: str
        """
        self._category_id = category_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Recommendation.
        The name assigned to the recommendation.


        :return: The name of this Recommendation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Recommendation.
        The name assigned to the recommendation.


        :param name: The name of this Recommendation.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this Recommendation.
        Text describing the recommendation.


        :return: The description of this Recommendation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Recommendation.
        Text describing the recommendation.


        :param description: The description of this Recommendation.
        :type: str
        """
        self._description = description

    @property
    def importance(self):
        """
        **[Required]** Gets the importance of this Recommendation.
        The level of importance assigned to the recommendation.

        Allowed values for this property are: "CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The importance of this Recommendation.
        :rtype: str
        """
        return self._importance

    @importance.setter
    def importance(self, importance):
        """
        Sets the importance of this Recommendation.
        The level of importance assigned to the recommendation.


        :param importance: The importance of this Recommendation.
        :type: str
        """
        allowed_values = ["CRITICAL", "HIGH", "MODERATE", "LOW", "MINOR"]
        if not value_allowed_none_or_none_sentinel(importance, allowed_values):
            importance = 'UNKNOWN_ENUM_VALUE'
        self._importance = importance

    @property
    def resource_counts(self):
        """
        **[Required]** Gets the resource_counts of this Recommendation.
        An array of `ResourceCount` objects grouped by the status of the resource actions.


        :return: The resource_counts of this Recommendation.
        :rtype: list[oci.optimizer.models.ResourceCount]
        """
        return self._resource_counts

    @resource_counts.setter
    def resource_counts(self, resource_counts):
        """
        Sets the resource_counts of this Recommendation.
        An array of `ResourceCount` objects grouped by the status of the resource actions.


        :param resource_counts: The resource_counts of this Recommendation.
        :type: list[oci.optimizer.models.ResourceCount]
        """
        self._resource_counts = resource_counts

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Recommendation.
        The recommendation's current state.

        Allowed values for this property are: "ACTIVE", "FAILED", "INACTIVE", "ATTACHING", "DETACHING", "DELETING", "DELETED", "UPDATING", "CREATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Recommendation.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Recommendation.
        The recommendation's current state.


        :param lifecycle_state: The lifecycle_state of this Recommendation.
        :type: str
        """
        allowed_values = ["ACTIVE", "FAILED", "INACTIVE", "ATTACHING", "DETACHING", "DELETING", "DELETED", "UPDATING", "CREATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def estimated_cost_saving(self):
        """
        **[Required]** Gets the estimated_cost_saving of this Recommendation.
        The estimated cost savings, in dollars, for the recommendation.


        :return: The estimated_cost_saving of this Recommendation.
        :rtype: float
        """
        return self._estimated_cost_saving

    @estimated_cost_saving.setter
    def estimated_cost_saving(self, estimated_cost_saving):
        """
        Sets the estimated_cost_saving of this Recommendation.
        The estimated cost savings, in dollars, for the recommendation.


        :param estimated_cost_saving: The estimated_cost_saving of this Recommendation.
        :type: float
        """
        self._estimated_cost_saving = estimated_cost_saving

    @property
    def status(self):
        """
        **[Required]** Gets the status of this Recommendation.
        The current status of the recommendation.

        Allowed values for this property are: "PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this Recommendation.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Recommendation.
        The current status of the recommendation.


        :param status: The status of this Recommendation.
        :type: str
        """
        allowed_values = ["PENDING", "DISMISSED", "POSTPONED", "IMPLEMENTED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_status_begin(self):
        """
        **[Required]** Gets the time_status_begin of this Recommendation.
        The date and time that the recommendation entered its current status. The format is defined by RFC3339.

        For example, \"The status of the recommendation changed from `pending` to `current(ignored)` on this date and time.\"


        :return: The time_status_begin of this Recommendation.
        :rtype: datetime
        """
        return self._time_status_begin

    @time_status_begin.setter
    def time_status_begin(self, time_status_begin):
        """
        Sets the time_status_begin of this Recommendation.
        The date and time that the recommendation entered its current status. The format is defined by RFC3339.

        For example, \"The status of the recommendation changed from `pending` to `current(ignored)` on this date and time.\"


        :param time_status_begin: The time_status_begin of this Recommendation.
        :type: datetime
        """
        self._time_status_begin = time_status_begin

    @property
    def time_status_end(self):
        """
        Gets the time_status_end of this Recommendation.
        The date and time the current status will change. The format is defined by RFC3339.

        For example, \"The current `postponed` status of the recommendation will end and change to `pending` on this
        date and time.\"


        :return: The time_status_end of this Recommendation.
        :rtype: datetime
        """
        return self._time_status_end

    @time_status_end.setter
    def time_status_end(self, time_status_end):
        """
        Sets the time_status_end of this Recommendation.
        The date and time the current status will change. The format is defined by RFC3339.

        For example, \"The current `postponed` status of the recommendation will end and change to `pending` on this
        date and time.\"


        :param time_status_end: The time_status_end of this Recommendation.
        :type: datetime
        """
        self._time_status_end = time_status_end

    @property
    def time_created(self):
        """
        Gets the time_created of this Recommendation.
        The date and time the recommendation details were created, in the format defined by RFC3339.


        :return: The time_created of this Recommendation.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Recommendation.
        The date and time the recommendation details were created, in the format defined by RFC3339.


        :param time_created: The time_created of this Recommendation.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Recommendation.
        The date and time the recommendation details were last updated, in the format defined by RFC3339.


        :return: The time_updated of this Recommendation.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Recommendation.
        The date and time the recommendation details were last updated, in the format defined by RFC3339.


        :param time_updated: The time_updated of this Recommendation.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def supported_levels(self):
        """
        Gets the supported_levels of this Recommendation.

        :return: The supported_levels of this Recommendation.
        :rtype: oci.optimizer.models.SupportedLevels
        """
        return self._supported_levels

    @supported_levels.setter
    def supported_levels(self, supported_levels):
        """
        Sets the supported_levels of this Recommendation.

        :param supported_levels: The supported_levels of this Recommendation.
        :type: oci.optimizer.models.SupportedLevels
        """
        self._supported_levels = supported_levels

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source import Source
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OciService(Source):
    """
    OCI service logging configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OciService object with values from keyword arguments. The default value of the :py:attr:`~oci.logging.models.OciService.source_type` attribute
        of this class is ``OCISERVICE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this OciService.
            Allowed values for this property are: "OCISERVICE"
        :type source_type: str

        :param service:
            The value to assign to the service property of this OciService.
        :type service: str

        :param resource:
            The value to assign to the resource property of this OciService.
        :type resource: str

        :param category:
            The value to assign to the category property of this OciService.
        :type category: str

        :param parameters:
            The value to assign to the parameters property of this OciService.
        :type parameters: dict(str, str)

        """
        self.swagger_types = {
            'source_type': 'str',
            'service': 'str',
            'resource': 'str',
            'category': 'str',
            'parameters': 'dict(str, str)'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'service': 'service',
            'resource': 'resource',
            'category': 'category',
            'parameters': 'parameters'
        }

        self._source_type = None
        self._service = None
        self._resource = None
        self._category = None
        self._parameters = None
        self._source_type = 'OCISERVICE'

    @property
    def service(self):
        """
        **[Required]** Gets the service of this OciService.
        Service generating log.


        :return: The service of this OciService.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this OciService.
        Service generating log.


        :param service: The service of this OciService.
        :type: str
        """
        self._service = service

    @property
    def resource(self):
        """
        **[Required]** Gets the resource of this OciService.
        The unique identifier of the resource emitting the log.


        :return: The resource of this OciService.
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """
        Sets the resource of this OciService.
        The unique identifier of the resource emitting the log.


        :param resource: The resource of this OciService.
        :type: str
        """
        self._resource = resource

    @property
    def category(self):
        """
        **[Required]** Gets the category of this OciService.
        Log object category.


        :return: The category of this OciService.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this OciService.
        Log object category.


        :param category: The category of this OciService.
        :type: str
        """
        self._category = category

    @property
    def parameters(self):
        """
        Gets the parameters of this OciService.
        Log category parameters are stored here.


        :return: The parameters of this OciService.
        :rtype: dict(str, str)
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this OciService.
        Log category parameters are stored here.


        :param parameters: The parameters of this OciService.
        :type: dict(str, str)
        """
        self._parameters = parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2018 Kenneth Reitz

# .-. .-. .-. . . .-. .-. .-. .-.
# |(  |-  |.| | | |-  `-.  |  `-.
# ' ' `-' `-`.`-' `-' `-'  '  `-'

__title__ = 'requests'
__description__ = 'Python HTTP for Humans.'
__url__ = 'https://requests.readthedocs.io'
__version__ = '2.25.1'
__build__ = 0x022501
__author__ = 'Kenneth Reitz'
__author_email__ = 'me@kennethreitz.org'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2020 Kenneth Reitz'
__cake__ = u'\u2728 \U0001f370 \u2728'



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApproveAccessRequestDetails(object):
    """
    Details of the access request approval.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApproveAccessRequestDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param approver_comment:
            The value to assign to the approver_comment property of this ApproveAccessRequestDetails.
        :type approver_comment: str

        :param audit_type:
            The value to assign to the audit_type property of this ApproveAccessRequestDetails.
        :type audit_type: list[str]

        :param additional_message:
            The value to assign to the additional_message property of this ApproveAccessRequestDetails.
        :type additional_message: str

        """
        self.swagger_types = {
            'approver_comment': 'str',
            'audit_type': 'list[str]',
            'additional_message': 'str'
        }

        self.attribute_map = {
            'approver_comment': 'approverComment',
            'audit_type': 'auditType',
            'additional_message': 'additionalMessage'
        }

        self._approver_comment = None
        self._audit_type = None
        self._additional_message = None

    @property
    def approver_comment(self):
        """
        Gets the approver_comment of this ApproveAccessRequestDetails.
        Comment by the approver during approval.


        :return: The approver_comment of this ApproveAccessRequestDetails.
        :rtype: str
        """
        return self._approver_comment

    @approver_comment.setter
    def approver_comment(self, approver_comment):
        """
        Sets the approver_comment of this ApproveAccessRequestDetails.
        Comment by the approver during approval.


        :param approver_comment: The approver_comment of this ApproveAccessRequestDetails.
        :type: str
        """
        self._approver_comment = approver_comment

    @property
    def audit_type(self):
        """
        Gets the audit_type of this ApproveAccessRequestDetails.
        Specifies the type of auditing to be enabled. There are two levels of auditing: command-level and keystroke-level.
        By default, auditing is enabled at the command level i.e., each command issued by the operator is audited. When keystroke-level is chosen,
        in addition to command level logging, key strokes are also logged.


        :return: The audit_type of this ApproveAccessRequestDetails.
        :rtype: list[str]
        """
        return self._audit_type

    @audit_type.setter
    def audit_type(self, audit_type):
        """
        Sets the audit_type of this ApproveAccessRequestDetails.
        Specifies the type of auditing to be enabled. There are two levels of auditing: command-level and keystroke-level.
        By default, auditing is enabled at the command level i.e., each command issued by the operator is audited. When keystroke-level is chosen,
        in addition to command level logging, key strokes are also logged.


        :param audit_type: The audit_type of this ApproveAccessRequestDetails.
        :type: list[str]
        """
        self._audit_type = audit_type

    @property
    def additional_message(self):
        """
        Gets the additional_message of this ApproveAccessRequestDetails.
        Message that needs to be displayed to the Ops User.


        :return: The additional_message of this ApproveAccessRequestDetails.
        :rtype: str
        """
        return self._additional_message

    @additional_message.setter
    def additional_message(self, additional_message):
        """
        Sets the additional_message of this ApproveAccessRequestDetails.
        Message that needs to be displayed to the Ops User.


        :param additional_message: The additional_message of this ApproveAccessRequestDetails.
        :type: str
        """
        self._additional_message = additional_message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateStackDetails(object):
    """
    Specifies which fields and the data for each to update on the specified stack.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateStackDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this UpdateStackDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this UpdateStackDetails.
        :type description: str

        :param config_source:
            The value to assign to the config_source property of this UpdateStackDetails.
        :type config_source: oci.resource_manager.models.UpdateConfigSourceDetails

        :param variables:
            The value to assign to the variables property of this UpdateStackDetails.
        :type variables: dict(str, str)

        :param terraform_version:
            The value to assign to the terraform_version property of this UpdateStackDetails.
        :type terraform_version: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateStackDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateStackDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'config_source': 'UpdateConfigSourceDetails',
            'variables': 'dict(str, str)',
            'terraform_version': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'config_source': 'configSource',
            'variables': 'variables',
            'terraform_version': 'terraformVersion',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._config_source = None
        self._variables = None
        self._terraform_version = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateStackDetails.
        The name of the stack.


        :return: The display_name of this UpdateStackDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateStackDetails.
        The name of the stack.


        :param display_name: The display_name of this UpdateStackDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this UpdateStackDetails.
        Description of the stack.


        :return: The description of this UpdateStackDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateStackDetails.
        Description of the stack.


        :param description: The description of this UpdateStackDetails.
        :type: str
        """
        self._description = description

    @property
    def config_source(self):
        """
        Gets the config_source of this UpdateStackDetails.

        :return: The config_source of this UpdateStackDetails.
        :rtype: oci.resource_manager.models.UpdateConfigSourceDetails
        """
        return self._config_source

    @config_source.setter
    def config_source(self, config_source):
        """
        Sets the config_source of this UpdateStackDetails.

        :param config_source: The config_source of this UpdateStackDetails.
        :type: oci.resource_manager.models.UpdateConfigSourceDetails
        """
        self._config_source = config_source

    @property
    def variables(self):
        """
        Gets the variables of this UpdateStackDetails.
        Terraform variables associated with this resource.
        The maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 8192 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :return: The variables of this UpdateStackDetails.
        :rtype: dict(str, str)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this UpdateStackDetails.
        Terraform variables associated with this resource.
        The maximum number of variables supported is 250.
        The maximum size of each variable, including both name and value, is 8192 bytes.
        Example: `{\"CompartmentId\": \"compartment-id-value\"}`


        :param variables: The variables of this UpdateStackDetails.
        :type: dict(str, str)
        """
        self._variables = variables

    @property
    def terraform_version(self):
        """
        Gets the terraform_version of this UpdateStackDetails.
        The version of Terraform to use with the stack. Example: `0.12.x`


        :return: The terraform_version of this UpdateStackDetails.
        :rtype: str
        """
        return self._terraform_version

    @terraform_version.setter
    def terraform_version(self, terraform_version):
        """
        Sets the terraform_version of this UpdateStackDetails.
        The version of Terraform to use with the stack. Example: `0.12.x`


        :param terraform_version: The terraform_version of this UpdateStackDetails.
        :type: str
        """
        self._terraform_version = terraform_version

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateStackDetails.
        Free-form tags associated with this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateStackDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateStackDetails.
        Free-form tags associated with this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateStackDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateStackDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateStackDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateStackDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateStackDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PathMatchType(object):
    """
    The type of matching to apply to incoming URIs.
    """

    #: A constant which can be used with the match_type property of a PathMatchType.
    #: This constant has a value of "EXACT_MATCH"
    MATCH_TYPE_EXACT_MATCH = "EXACT_MATCH"

    #: A constant which can be used with the match_type property of a PathMatchType.
    #: This constant has a value of "FORCE_LONGEST_PREFIX_MATCH"
    MATCH_TYPE_FORCE_LONGEST_PREFIX_MATCH = "FORCE_LONGEST_PREFIX_MATCH"

    #: A constant which can be used with the match_type property of a PathMatchType.
    #: This constant has a value of "PREFIX_MATCH"
    MATCH_TYPE_PREFIX_MATCH = "PREFIX_MATCH"

    #: A constant which can be used with the match_type property of a PathMatchType.
    #: This constant has a value of "SUFFIX_MATCH"
    MATCH_TYPE_SUFFIX_MATCH = "SUFFIX_MATCH"

    def __init__(self, **kwargs):
        """
        Initializes a new PathMatchType object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param match_type:
            The value to assign to the match_type property of this PathMatchType.
            Allowed values for this property are: "EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type match_type: str

        """
        self.swagger_types = {
            'match_type': 'str'
        }

        self.attribute_map = {
            'match_type': 'matchType'
        }

        self._match_type = None

    @property
    def match_type(self):
        """
        **[Required]** Gets the match_type of this PathMatchType.
        Specifies how the load balancing service compares a :func:`path_route`
        object's `path` string against the incoming URI.

        *  **EXACT_MATCH** - Looks for a `path` string that exactly matches the incoming URI path.

        *  **FORCE_LONGEST_PREFIX_MATCH** - Looks for the `path` string with the best, longest match of the beginning
           portion of the incoming URI path.

        *  **PREFIX_MATCH** - Looks for a `path` string that matches the beginning portion of the incoming URI path.

        *  **SUFFIX_MATCH** - Looks for a `path` string that matches the ending portion of the incoming URI path.

        For a full description of how the system handles `matchType` in a path route set containing multiple rules, see
        `Managing Request Routing`__.

        __ https://docs.cloud.oracle.com/Content/Balance/Tasks/managingrequest.htm

        Allowed values for this property are: "EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The match_type of this PathMatchType.
        :rtype: str
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """
        Sets the match_type of this PathMatchType.
        Specifies how the load balancing service compares a :func:`path_route`
        object's `path` string against the incoming URI.

        *  **EXACT_MATCH** - Looks for a `path` string that exactly matches the incoming URI path.

        *  **FORCE_LONGEST_PREFIX_MATCH** - Looks for the `path` string with the best, longest match of the beginning
           portion of the incoming URI path.

        *  **PREFIX_MATCH** - Looks for a `path` string that matches the beginning portion of the incoming URI path.

        *  **SUFFIX_MATCH** - Looks for a `path` string that matches the ending portion of the incoming URI path.

        For a full description of how the system handles `matchType` in a path route set containing multiple rules, see
        `Managing Request Routing`__.

        __ https://docs.cloud.oracle.com/Content/Balance/Tasks/managingrequest.htm


        :param match_type: The match_type of this PathMatchType.
        :type: str
        """
        allowed_values = ["EXACT_MATCH", "FORCE_LONGEST_PREFIX_MATCH", "PREFIX_MATCH", "SUFFIX_MATCH"]
        if not value_allowed_none_or_none_sentinel(match_type, allowed_values):
            match_type = 'UNKNOWN_ENUM_VALUE'
        self._match_type = match_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Source(object):
    """
    The properties that define a source. Source refers to the source environment from which you migrate an application to Oracle Cloud
    Infrastructure. For more information, see `Manage Sources`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized, talk to an administrator. If you're
    an administrator who needs to write policies to give users access, see `Getting Started with
    Policies`__.

    __ https://docs.cloud.oracle.com/iaas/application-migration/manage_sources.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Source.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    def __init__(self, **kwargs):
        """
        Initializes a new Source object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Source.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Source.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this Source.
        :type display_name: str

        :param description:
            The value to assign to the description property of this Source.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this Source.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Source.
            Allowed values for this property are: "CREATING", "DELETING", "UPDATING", "ACTIVE", "INACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Source.
        :type lifecycle_details: str

        :param source_details:
            The value to assign to the source_details property of this Source.
        :type source_details: oci.application_migration.models.SourceDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Source.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Source.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'source_details': 'SourceDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'description': 'description',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'source_details': 'sourceDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._compartment_id = None
        self._display_name = None
        self._description = None
        self._time_created = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._source_details = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        Gets the id of this Source.
        The `OCID`__ of the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this Source.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Source.
        The `OCID`__ of the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this Source.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Source.
        The `OCID`__ of the compartment that contains the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Source.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Source.
        The `OCID`__ of the compartment that contains the source.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Source.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this Source.
        Name of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :return: The display_name of this Source.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Source.
        Name of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :param display_name: The display_name of this Source.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this Source.
        Description of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :return: The description of this Source.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Source.
        Description of the source. This helps you to identify the appropriate source environment when you have multiple sources defined.


        :param description: The description of this Source.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        Gets the time_created of this Source.
        The date and time at which the source was created, in the format defined by RFC3339.


        :return: The time_created of this Source.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Source.
        The date and time at which the source was created, in the format defined by RFC3339.


        :param time_created: The time_created of this Source.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Source.
        The current state of the source.

        Allowed values for this property are: "CREATING", "DELETING", "UPDATING", "ACTIVE", "INACTIVE", "DELETED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Source.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Source.
        The current state of the source.


        :param lifecycle_state: The lifecycle_state of this Source.
        :type: str
        """
        allowed_values = ["CREATING", "DELETING", "UPDATING", "ACTIVE", "INACTIVE", "DELETED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Source.
        Details about the current lifecycle state of the source.


        :return: The lifecycle_details of this Source.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Source.
        Details about the current lifecycle state of the source.


        :param lifecycle_details: The lifecycle_details of this Source.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def source_details(self):
        """
        Gets the source_details of this Source.

        :return: The source_details of this Source.
        :rtype: oci.application_migration.models.SourceDetails
        """
        return self._source_details

    @source_details.setter
    def source_details(self, source_details):
        """
        Sets the source_details of this Source.

        :param source_details: The source_details of this Source.
        :type: oci.application_migration.models.SourceDetails
        """
        self._source_details = source_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Source.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Source.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Source.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Source.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Source.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Source.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Source.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__. Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Source.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ManagementAgentPluginAggregation(object):
    """
    A count of Management Agents Plugins sharing the values for specified dimensions.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ManagementAgentPluginAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimensions:
            The value to assign to the dimensions property of this ManagementAgentPluginAggregation.
        :type dimensions: oci.management_agent.models.ManagementAgentPluginAggregationDimensions

        :param count:
            The value to assign to the count property of this ManagementAgentPluginAggregation.
        :type count: int

        """
        self.swagger_types = {
            'dimensions': 'ManagementAgentPluginAggregationDimensions',
            'count': 'int'
        }

        self.attribute_map = {
            'dimensions': 'dimensions',
            'count': 'count'
        }

        self._dimensions = None
        self._count = None

    @property
    def dimensions(self):
        """
        Gets the dimensions of this ManagementAgentPluginAggregation.

        :return: The dimensions of this ManagementAgentPluginAggregation.
        :rtype: oci.management_agent.models.ManagementAgentPluginAggregationDimensions
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this ManagementAgentPluginAggregation.

        :param dimensions: The dimensions of this ManagementAgentPluginAggregation.
        :type: oci.management_agent.models.ManagementAgentPluginAggregationDimensions
        """
        self._dimensions = dimensions

    @property
    def count(self):
        """
        Gets the count of this ManagementAgentPluginAggregation.
        The number of Management Agent Plugins in this group


        :return: The count of this ManagementAgentPluginAggregation.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ManagementAgentPluginAggregation.
        The number of Management Agent Plugins in this group


        :param count: The count of this ManagementAgentPluginAggregation.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
